com.nervestaple.hl7-parser.parser


add-fieldclj/s

(add-field segment field)

Adds the provided field map to the provided segment map and returns a new segment.

Adds the provided field map to the provided segment map and returns a new
segment.
sourceraw docstring

add-fieldsclj/s

(add-fields segment fields)

Adds the provided field maps to the provided segment map and returns a new segment.

Adds the provided field maps to the provided segment map and returns a new
segment.
sourceraw docstring

add-segmentclj/s

(add-segment message segment)

Adds the provided segment map to the provided message map and returns a new message.

Adds the provided segment map to the provided message map and returns a new
message.
sourceraw docstring

ASCII_AMPERSANDclj/s

source

ASCII_BACKSLASHclj/s

source

ASCII_CARATclj/s

source

ASCII_CRclj/s

source

ASCII_FSclj/s

source

ASCII_LFclj/s

source

ASCII_PIPEclj/s

source

ASCII_TILDEclj/s

source

ASCII_VTclj/s

source

convert-valuesclj/s

(convert-values values)

If provided a list of values, any in items are replaced with an empty string. When provided a single value a list with that value will be returned or an empty list of that value is nil.

If provided a list of values, any in items are replaced with an empty string.
When provided a single value a list with that value will be returned or an
empty list of that value is nil.
sourceraw docstring

create-empty-messageclj/s

(create-empty-message)
(create-empty-message delimiters)

Returns a new, empty message map. if no map of delimiters is provided then the default set will be used.

Returns a new, empty message map. if no map of delimiters is provided then the
default set will be used.
sourceraw docstring

create-fieldclj/s

(create-field)
(create-field data)

Returns a new field map populated with the provided data.

Returns a new field map populated with the provided data.
sourceraw docstring

create-messageclj/s

(create-message delimiters & segments)

Accepts a map of delimiters and segments. Returns a new parsed message using the provided delimiters populated with the provided segments.

Accepts a map of delimiters and segments. Returns a new parsed message using
the provided delimiters populated with the provided segments.
sourceraw docstring

create-segmentclj/s

(create-segment id & fields)

Returns a new, empty segment map with the provided id.

Returns a new, empty segment map with the provided id.
sourceraw docstring

DEFAULT-DELIMITERSclj/s

source

format-timestampclj/s

(format-timestamp)
(format-timestamp date)

Returns an HL7 compatible timestamp (yyyyMMddHHmmss) in local time for the provided date (a java.util.Date or a JavaScript Date), or for the current time if no date is provided.

Returns an HL7 compatible timestamp (yyyyMMddHHmmss) in local time for the
provided date (a java.util.Date or a JavaScript Date), or for the current time
if no date is provided.
sourceraw docstring

get-readerclj/smultimethod

Returns a pushback reader for the provided Object. We want to wrap another Reader but we'll cast to a String and read that if required. On ClojureScript the Object is always read as a String.

Returns a pushback reader for the provided Object. We want to wrap
another Reader but we'll cast to a String and read that if
required. On ClojureScript the Object is always read as a String.
sourceraw docstring

parseclj/s

(parse message-source)

Reads data from the provided source (a Reader, String, etc.) and parses that data into a map that represents the content of the message.

Reads data from the provided source (a Reader, String, etc.) and parses that
data into a map that represents the content of the message.
sourceraw docstring

pr-delimitersclj/s

(pr-delimiters delimiters)

Returns an HL7 compatible text representation of the provided delimiters.

Returns an HL7 compatible text representation of the provided
delimiters.
sourceraw docstring

pr-fieldclj/s

(pr-field delimiters field)

Returns an HL7 compatible String representation of the provided field.

Returns an HL7 compatible String representation of the provided
field.
sourceraw docstring

pr-messageclj/s

(pr-message message)

Prints the provided HL7 message to the current out stream.

Prints the provided HL7 message to the current *out* stream.
sourceraw docstring

pr-segmentclj/s

(pr-segment delimiters segment)

Returns an HL7 compatible String representation of the provided segment.

Returns an HL7 compatible String representation of the provided
segment.
sourceraw docstring

SEGMENT-DELIMITERclj/s

source

str-messageclj/s

(str-message message)

Returns the provided HL7 message as a string.

Returns the provided HL7 message as a string.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries