(add-field segment field)Adds the provided field map to the provided segment map and returns a new segment.
Adds the provided field map to the provided segment map and returns a new segment.
(add-fields segment fields)Adds the provided field maps to the provided segment map and returns a new segment.
Adds the provided field maps to the provided segment map and returns a new segment.
(add-segment message segment)Adds the provided segment map to the provided message map and returns a new message.
Adds the provided segment map to the provided message map and returns a new message.
(convert-values values)If provided a list of values, any in items are replaced with an empty string. When provided a single value a list with that value will be returned or an empty list of that value is nil.
If provided a list of values, any in items are replaced with an empty string. When provided a single value a list with that value will be returned or an empty list of that value is nil.
(create-empty-message)(create-empty-message delimiters)Returns a new, empty message map. if no map of delimiters is provided then the default set will be used.
Returns a new, empty message map. if no map of delimiters is provided then the default set will be used.
(create-field)(create-field data)Returns a new field map populated with the provided data.
Returns a new field map populated with the provided data.
(create-message delimiters & segments)Accepts a map of delimiters and segments. Returns a new parsed message using the provided delimiters populated with the provided segments.
Accepts a map of delimiters and segments. Returns a new parsed message using the provided delimiters populated with the provided segments.
(create-segment id & fields)Returns a new, empty segment map with the provided id.
Returns a new, empty segment map with the provided id.
(format-timestamp)(format-timestamp date)Returns an HL7 compatible timestamp (yyyyMMddHHmmss) in local time for the provided date (a java.util.Date or a JavaScript Date), or for the current time if no date is provided.
Returns an HL7 compatible timestamp (yyyyMMddHHmmss) in local time for the provided date (a java.util.Date or a JavaScript Date), or for the current time if no date is provided.
Returns a pushback reader for the provided Object. We want to wrap another Reader but we'll cast to a String and read that if required. On ClojureScript the Object is always read as a String.
Returns a pushback reader for the provided Object. We want to wrap another Reader but we'll cast to a String and read that if required. On ClojureScript the Object is always read as a String.
(parse message-source)Reads data from the provided source (a Reader, String, etc.) and parses that data into a map that represents the content of the message.
Reads data from the provided source (a Reader, String, etc.) and parses that data into a map that represents the content of the message.
(pr-delimiters delimiters)Returns an HL7 compatible text representation of the provided delimiters.
Returns an HL7 compatible text representation of the provided delimiters.
(pr-field delimiters field)Returns an HL7 compatible String representation of the provided field.
Returns an HL7 compatible String representation of the provided field.
(pr-message message)Prints the provided HL7 message to the current out stream.
Prints the provided HL7 message to the current *out* stream.
(pr-segment delimiters segment)Returns an HL7 compatible String representation of the provided segment.
Returns an HL7 compatible String representation of the provided segment.
(str-message message)Returns the provided HL7 message as a string.
Returns the provided HL7 message as a string.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |